pub struct Decoder<'a> { /* fields omitted */ }Expand description
A struct for decoding bytes.
This is not part of the MiniTxRx struct itself because we do not want to
require access to resources when decoding bytes.
impl<T> Any for T where
T: 'static + ?Sized, [src]
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>, [src]
impl<T, U> TryFrom<U> for T where
U: Into<T>, [src]
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.