Struct mini_rxtx::StdDecoder [−][src]
pub struct StdDecoder { /* fields omitted */ }Expand description
A struct for decoding bytes.
This is similar to Decoder but uses std to allocate a buffer.
This is not part of the MiniTxRx struct itself because we do not want to
require access to resources when decoding bytes.
Implementations
impl StdDecoder[src]
impl StdDecoder[src]