Struct mini_rxtx::StdDecoder [−][src]
pub struct StdDecoder { /* fields omitted */ }A struct for decoding bytes.
This is similar to Decoder but uses std to allocate a buffer.
This is not part of the MiniTxRx struct itself because we do not want to
require access to resources when decoding bytes.
Implementations
impl StdDecoder[src]
impl StdDecoder[src]Auto Trait Implementations
impl RefUnwindSafe for StdDecoder
impl RefUnwindSafe for StdDecoderimpl Send for StdDecoder
impl Send for StdDecoderimpl Sync for StdDecoder
impl Sync for StdDecoderimpl Unpin for StdDecoder
impl Unpin for StdDecoderimpl UnwindSafe for StdDecoder
impl UnwindSafe for StdDecoder